# Anonymized Credit Card Fraud Detection Package

Creating this package so that I can deploy this code on pip.

Next, I need to import this while deploying the code as an Airflow task.

All this because `PythonVirtualenvOperator()` doesn't let you access outside scripts from the virtual env.

Have created modular scripts for train and test time.